from DevExpress.LookAndFeel import UserLookAndFeel, DefaultLookAndFeel, SkinStyle, SkinSvgPalette


class BDStyle(object):
    def Skin(self, style):
        if style == "wxi":
            _style = SkinStyle.WXI
        elif style == "wxi-freshness":
            _style = SkinSvgPalette.WXI.Freshness
        elif style == "wxi-darkness":
            _style = SkinSvgPalette.WXI.Darkness
        elif style == "wxi-clearness":
            _style = SkinSvgPalette.WXI.Clearness
        elif style == "wxi-sharpness":
            _style = SkinSvgPalette.WXI.Sharpness
        elif style == "wxi-calmness":
            _style = SkinSvgPalette.WXI.Calmness
        if style == "wxicompact":
            _style = SkinStyle.WXICompact
        elif style == "wxicompact-freshness":
            _style = SkinSvgPalette.WXICompact.Freshness
        elif style == "wxicompact-darkness":
            _style = SkinSvgPalette.WXICompact.Darkness
        elif style == "wxicompact-clearness":
            _style = SkinSvgPalette.WXICompact.Clearness
        elif style == "wxicompact-sharpness":
            _style = SkinSvgPalette.WXICompact.Sharpness
        elif style == "wxicompact-calmness":
            _style = SkinSvgPalette.WXICompact.Calmness
        UserLookAndFeel.Default.SetSkinStyle(_style)


from bird_devexpress.ui.window import BDWindow
from bird_devexpress.ui.panel import BDPanel
from bird_devexpress.ui.widget import BDWidget


class BDFluentWindow(BDWindow):
    def Init(self):
        from DevExpress.XtraBars.FluentDesignSystem import FluentDesignForm
        self._ = FluentDesignForm()


class BDFluentWindowContainer(BDPanel):
    def Init(self):
        from DevExpress.XtraBars.FluentDesignSystem import FluentDesignFormContainer
        self._ = FluentDesignFormContainer()


class BDFluentWindowWidget(BDWidget):
    def Init(self):
        from DevExpress.XtraBars.FluentDesignSystem import FluentDesignFormControl
        self._ = FluentDesignFormControl()

    def FluentWindow(self, Window: BDFluentWindow):
        self._.FluentDesignForm = Window.Get()


from bird_form.windows.panel import BFPanel
from bird_devexpress.ui.widget import BDWidget


class BDPanel(BFPanel, BDWidget):
    def Init(self):
        from DevExpress.XtraEditors import PanelControl
        self._ = PanelControl()


from bird_devexpress.ui.widget import BDWidget
from bird_form.windows.window import BFWindow


class BDWindow(BFWindow, BDWidget):
    def Init(self):
        from DevExpress.XtraEditors import XtraForm
        self._ = XtraForm()


from bird_form.windows.button import BFButton
from bird_devexpress.ui.widget import BDWidget


class BDButton(BFButton, BDWidget):
    def Init(self):
        from DevExpress.XtraEditors import SimpleButton
        self._ = SimpleButton()



from clr import AddReference
from bird_devexpress import (devexpress_xtra_bars, devexpress_xtra_editors, devexpress_bonus_skins, devexpress_utils,
                             devexpress_xtra_richedit)

AddReference(devexpress_utils)
AddReference(devexpress_xtra_bars)
AddReference(devexpress_xtra_editors)
AddReference(devexpress_xtra_richedit)
AddReference(devexpress_bonus_skins)

from bird_devexpress.ui.widget import BDWidget
from bird_devexpress.ui.window import BDWindow
from bird_devexpress.ui.fluentwindow import BDFluentWindow, BDFluentWindowContainer, BDFluentWindowWidget
from bird_devexpress.ui.button import BDButton
from bird_devexpress.ui.toggle import BDToggleSwitch
from bird_devexpress.ui.richedit import BDRichEdit
from bird_devexpress.ui.style import BDStyle
from bird_devexpress.ui.settings import BDUseDirectX
from bird_devexpress.ui.taskbar_assistant import BDTaskBarAssistant, BDTaskBarButtonProgressMode
from bird_devexpress.ui.panel import BDPanel
from bird_devexpress.ui.tab import BDTab, BDTabNavigationPage, BDTabPane, BDTabPage


from bird_form.windows.button import BFButton
from bird_devexpress.ui.widget import BDWidget


class BDRichEdit(BDWidget):
    def __init__(self, Text: str = ""):
        super().__init__()
        self.SetText(Text)

    def Init(self):
        from DevExpress.XtraRichEdit import RichEditControl
        self._ = RichEditControl()

    def SetText(self, Text: str):
        self._.Text = Text

    def GetText(self):
        return self._.Text


import os
lib = os.path.dirname(__file__).replace("\\", "//")

devexpress_utils = lib + "//ui//DevExpress.Utils.v22.2.dll"

devexpress_xtra_bars = lib + "//ui//DevExpress.XtraBars.v22.2.dll"
devexpress_xtra_editors = lib + "//ui//DevExpress.XtraEditors.v22.2.dll"
devexpress_xtra_richedit = lib + "//ui//DevExpress.XtraEditors.v22.2.dll"

devexpress_bonus_skins = lib + "//ui//DevExpress.BonusSkins.v22.2.dll"


from bird_devexpress.ui import *



from DevExpress.Utils.Taskbar import TaskbarAssistant
from DevExpress.Utils.Taskbar.Core import TaskbarButtonProgressMode
from bird import BObject


BDTaskBarButtonProgressMode = TaskbarButtonProgressMode


class BDTaskBarAssistant(BObject):
    def Init(self):
        self._ = TaskbarAssistant()

    def SetProgressValue(self, Value: int):
        self._.ProgressCurrentValue = Value

    def GetProgressValue(self):
        return self._.ProgressCurrentValue

    def SetProgressMode(self, Mode):
        self._.ProgressMode = Mode


from bird_form.windows.tab import BFTab
from bird_form.windows.panel import BFPanel
from bird_devexpress.ui.widget import BDWidget


class BDTabNavigationPage(BFPanel, BDWidget):
    def __init__(self, Caption: str):
        super().__init__()
        self.SetCaption(Caption)

    def Init(self):
        from DevExpress.XtraBars.Navigation import TabNavigationPage
        self._ = TabNavigationPage()

    def SetCaption(self, Text: str):
        self._.Caption = Text


class BDTabPane(BFTab, BDWidget):
    def Init(self):
        from DevExpress.XtraBars.Navigation import TabPane
        self._ = TabPane()


class BDTabPage(BFPanel, BDWidget):
    def Init(self):
        from DevExpress.XtraTab import XtraTabPage
        self._ = XtraTabPage()


class BDTab(BFTab, BDWidget):
    def Init(self):
        from DevExpress.XtraTab import XtraTabControl
        self._ = XtraTabControl()

    def TabAdd(self, Widget):
        self._.TabPages.AddRange(Widget.Get())


from bird_form.windows.button import BFButton
from bird_devexpress.ui.widget import BDWidget


class BDToggleSwitch(BFButton, BDWidget):
    def __init__(self, Text: str = ""):
        super().__init__(Text=Text)

    def Init(self):
        from DevExpress.XtraEditors import ToggleSwitch
        self._ = ToggleSwitch()

    def SetOn(self, On: bool):
        self._.IsOn = On

    def IsOn(self):
        return self._.IsOn

    def BindToggle(self, Func):
        self._.Toggled += Func